#
# spec file for package numatop
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           numatop
Version:        2.5.1
Release:        1.2
Summary:        A top-like tool for runtime memory locality monitoring on NUMA systems
License:        BSD-3-Clause
Group:          System/Monitoring
URL:            https://01.org/numatop
Source0:        https://github.com/intel/%{name}/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  check-devel
BuildRequires:  libnuma-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64 ppc64le

%description
NumaTOP is an observation tool for runtime memory locality characterization
and analysis of processes and threads running on a NUMA system. It helps the
user characterize the NUMA behavior of processes and threads and identify
where the NUMA-related performance bottlenecks reside.
Numatop is supported on Intel Xeon processors: 5500-series, 6500/7500-series,
5600 series, E7-x8xx-series, and E5-16xx/24xx/26xx/46xx-series.
E5-16xx/24xx/26xx/46xx-series should be updated to latest CPU microcode
(microcode must be 0x618+ or 0x70c+). Kernel 3.9 or higher is required.

%prep
%setup -q -n %{name}-%{version}
%autopatch -p1

%build
autoreconf -i
%configure
# there seems to be wrong order of libnumatop.la and $(NCURSES_LIBS) in Makefile.am
make %{?_smp_mflags} LDFLAGS="-lncursesw -lncurses"

%install
%make_install

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_mandir}/man8/%{name}.8%{ext_man}

%changelog
* Sat Feb  8 2025 Dirk Müller <dmueller@suse.com>
- update to 2.5.1:
  * no changes
* Wed Dec 11 2024 Vlastimil Babka <vbabka@suse.com>
- update to version 2.5
  * Support GNR processors (jsc#PED-10182, jsc#PED-10575)
  * Support SRF processors (jsc#PED-10588)
- remove numatop-fix-missing-fields.patch: upstream
- remove numatop-power11.patch: upstream
* Tue Oct 15 2024 Vlastimil Babka <vbabka@suse.com>
- numatop-fix-missing-fields.patch: Fix building with recent gcc
- numatop-power11.patch: Support Power11 processors (jsc#PED-9887,
  jsc#PED-10899)
* Tue Jan 16 2024 Vlastimil Babka <vbabka@suse.com>
- update to version 2.4
  * Support EMR processors (jsc#PED-6059, jsc#PED-6038)
  * Support Power10 processors (jsc#PED-5450, jsc#PED-5667)
  * Support Zen3, Zen4 processors
* Fri Nov 18 2022 Vlastimil Babka <vbabka@suse.com>
- update to version 2.3
  * Add support for SPR CPUs (jsc#PED-2015)
* Thu Nov 25 2021 Vlastimil Babka <vbabka@suse.com>
- update to version 2.2
  * Support ICX processors (jsc#SLE-19499)
  * Sources downloaded from git tag, no proper upstream release.
  * Needs autoreconf.
* Mon Dec  3 2018 Vlastimil Babka <vbabka@suse.com>
- update to version 2.1
  * Add ppc64le support
  * New autotools-based build system
* Mon Nov 19 2018 Cristian Rodríguez <crrodriguez@opensuse.org>
- numatop-ncursesw.patch: Switch to ncursesw6
* Sat Mar 26 2016 mpluskal@suse.com
- Update to version 1.0.4
  * Add BDW-EP/EX support
* Fri Mar  6 2015 p.drouand@gmail.com
- Update to version 1.0.3
  * Add Haswell supporting
* Sun Aug 18 2013 vbabka@suse.com
- Restrict to x86_64 due to Intel CPU requirement and missing deps
  on x86.
* Thu Aug 15 2013 vbabka@suse.com
- Initial package
